<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
 
Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.
 
The Original Code is comprised of the PT Calendar directory
 
The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2013.
All Rights Reserved.
 
By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable
end user license agreement.
--->

<!---
/* *************************************************************** */
Author: 	
	PaperThin, Inc.
	G. Cronkright
Custom Field Type:
	approval track checkbox
Name:
	approval_track_checkboxes_render.cfm
Summary:
	A custom checkbox field that also captures the dataTime stamp and the CS UserID and copies
	those values to other fields in the form. Field IDs can be set in the props for the other 
	text or hidden fields in the same form.
ADF Requirements:
	date_1_0
	scripts_1_0
History:
	2011-07-28 - GAC - Created
	2012-01-27 - GAC - Added update for CS 6.x for field permissions / backwards compatible for CS 5.x
--->
<cfscript>
	// the fields current value
	currentValue = attributes.currentValues[fqFieldName];
	// the param structure which will hold all of the fields from the props dialog
	xparams = parameters[fieldQuery.inputID];

	if ( NOT StructKeyExists(xparams, "fldClass") )
		xparams.fldClass = "";
		
	if ( NOT StructKeyExists(xparams, "fldName") )
		xparams.fldName = fqFieldName;
	else if ( LEN(TRIM(xparams.fldName)) EQ 0 )
		xparams.fldName = ReplaceNoCase(xParams.fieldName,'fic_','');
	
	// Set the value that is stored when the checkbox is checked
	if ( NOT StructKeyExists(xparams, "checkedVal") )
		xparams.checkedVal = "yes";
	// Set the value that is stored when the checkbox is checked
	if ( NOT StructKeyExists(xparams, "uncheckedVal") )
		xparams.uncheckedVal = "no";
		
	// FieldID used to capture the Approval dateTime stamp
	if( not structKeyExists(xparams, "fldDateTime") )
		xparams.fldDateTime = "";
	else
		xparams.fldDateTime = TRIM(xparams.fldDateTime);	
	// FieldID used to capture the Approver userID
	if( not structKeyExists(xparams, "fldUserID") )
		xparams.fldUserID = "";	
	else
		xparams.fldUserID = TRIM(xparams.fldUserID);
	// FieldID of the Denial Reason Text Area field
	if( not structKeyExists(xparams, "fldDenialMsg") )
		xparams.fldDenialMsg = "";	
	else
		xparams.fldDenialMsg = TRIM(xparams.fldDenialMsg);
		
	// FieldID of the Denial Value Text Area field
	if( not structKeyExists(xparams, "deniedVal") )
		xparams.deniedVal = "";	
	else
		xparams.deniedVal = TRIM(xparams.deniedVal);	
		
	// FieldID of the Denial Checkbox Label
	if( not structKeyExists(xparams, "deniedLabel") OR LEN(TRIM(xparams.deniedLabel)) EQ 0 )
		xparams.deniedLabel = "Denied";	
	else
		xparams.deniedLabel = TRIM(xparams.deniedLabel);	
	// FieldID of the Approved Checkbox Value
	if( not structKeyExists(xparams, "approvedLabel") )
		xparams.approvedLabel = "";	
	else
		xparams.approvedLabel = TRIM(xparams.approvedLabel);
		
	// Set the DEFAULT Approved Label if a Denied Label has been set but no Approved Label
	if ( LEN(TRIM(xparams.deniedVal)) AND LEN(TRIM(xparams.deniedLabel)) AND LEN(TRIM(xparams.approvedLabel)) EQ 0 )
		xparams.approvedLabel = "Approved";

	// Get the Now() dateTimeStamp formated for CommonSpot
	csDateTimeStamp = application.ptCalendar.date.csDateFormat(Now(),Now());
	
	// Set the field ID from the field name
	xparams.fldID = TRIM(xparams.fldName);
	
	// Check the default value
	if ( LEN(currentValue) LTE 0 ) 
	{
		currentValue = xparams.uncheckedVal; //'no'
		// If defaulted to checked
		if ( xparams.defaultVal EQ "yes" )
			currentValue = xparams.checkedVal; //'yes'
		else if ( xparams.defaultVal EQ "denied" AND LEN(TRIM(xparams.deniedVal)) )
			currentValue = xparams.deniedVal; //'denied'
	}
	
	// Set defaults for the label and description 
	includeLabel = true;
	includeDescription = true; 
	
	//-- Update for CS 6.x / backwards compatible for CS 5.x --
	//   If it does not exist set the Field Security variable to a default value
	if ( NOT StructKeyExists(variables,"fieldPermission") )
		variables.fieldPermission = "";
		
	//-- Read Only Check w/ cs6 fieldPermission parameter --
	readOnly = application.ADF.forms.isFieldReadOnly(xparams,variables.fieldPermission);
		
	tempFieldsType = "hidden"; //defualt: 'hidden' option: 'text' 
	
	// for debugging set to TRUE
	cftDebug = false; // default: false
	if ( cftDebug )
		tempFieldsType = "text";
		
	// Load JQuery to the script
	application.ptCalendar.scripts.loadJQuery();
	// Load JQuery to the script - use this more complicated checkbox option, etc.
	application.ptCalendar.scripts.loadJQueryCheckboxes();
</cfscript>
<!--- <cfdump var="#xparams#"> --->

<cfoutput>
	<script>
		// javascript validation to make sure they have text to be converted
		#fqFieldName# = new Object();
		#fqFieldName#.id = '#fqFieldName#';
		#fqFieldName#.tid = #rendertabindex#;
		
		//#fqFieldName#.validator = "validateLength()";
		//#fqFieldName#.msg = "Please upload a document.";
		// push on to validation array
		//vobjects_#attributes.formname#.push(#fqFieldName#);
		
		jQuery(function(){
			jQuery.radioCheckboxGroup("#fqFieldName#_checkbox");
			
			// Check if we are rendering the field 
			if ( '#xparams.renderField#' == 'yes' ) {
			
				// Set the value of the checkbox based on the Stored field value
				if ( jQuery('input[name=#fqFieldName#]').val() == '#xparams.checkedVal#' ) {
					jQuery('###xparams.fldID#_checkbox_approved').attr('checked', 'checked');
				}
				<cfif LEN(TRIM(xparams.deniedVal))>
				else if ( jQuery('input[name=#fqFieldName#]').val() == '#xparams.deniedVal#' ) {
					jQuery('###xparams.fldID#_checkbox_denied').attr('checked', 'checked');
				}
				</cfif>
				else {
					jQuery('###xparams.fldID#_checkbox_approved').removeAttr('checked');	
					<cfif LEN(TRIM(xparams.deniedVal))>	
					jQuery('###xparams.fldID#_checkbox_denied').removeAttr('checked');	
					</cfif>			
				}
				
				<cfif !readOnly>			
				// On Checkbox (or Checkboxes) Change Action
				jQuery('input[name=#fqFieldName#_checkbox]').change(function(){
					clickedID = jQuery(this).attr("id");
					clickedValue = jQuery(this).val();
					if ( jQuery("##" + clickedID).attr("checked") && clickedValue == 1 ) {
						currVal = "#xparams.checkedVal#";
					}
					<cfif LEN(TRIM(xparams.deniedVal))>
					else if ( jQuery("##" + clickedID).attr("checked") && clickedValue == 0 ) {
						currVal = "#xparams.deniedVal#";												
					}
					</cfif>
					else {
						currVal = "#xparams.uncheckedVal#";
					}
					
					// Set the field value to be stored for this field
					jQuery('input[name=#fqFieldName#]').val(currVal);
					
					<cfif LEN(TRIM(xparams.fldUserID))>	 
					// Call the Update ApprovalUserID function 
					updateApprovalUserID_#fqFieldName#();
					</cfif>
					<cfif LEN(TRIM(xparams.fldDateTime))>
					// Call the Update Approved DateTime function  
					updateApprovedDateTime_#fqFieldName#();
					</cfif>
					<cfif LEN(TRIM(xparams.fldDenialMsg))>
					// Call the showHideDenialMsg function	  
					showHideDenialMsg_#fqFieldName#();
					</cfif>
				});
				</cfif>
			}
			else {
				// Hide the field row
				jQuery("###fqFieldName#_FIELD_ROW").hide();
				jQuery("###fqFieldName#_DESCRIPTION_ROW").hide();
			}

			// If we have a fldDenialMsg Binding and the Denied Checkbox is checked show the Denial Message Field
			<cfif LEN(TRIM(xparams.fldDenialMsg))>
				showHideDenialMsg_#fqFieldName#();
			</cfif>	
		});	
		
		// Set the Approved UserID if the UserID Field ID binding is set
		<cfif LEN(TRIM(xparams.fldUserID))>	  
		function updateApprovalUserID_#fqFieldName#() {
			var apprvlUserID = jQuery("###xparams.fldID#_userid").val();
			jQuery("###xparams.fldUserID#").val(apprvlUserID);		
		}	  
		</cfif>	
		 
		// Set the Approved DateTime Stamp if the DateTime Field ID binding is set
		<cfif LEN(TRIM(xparams.fldDateTime))>	  
		function updateApprovedDateTime_#fqFieldName#(){
			var apprvlDateTime = jQuery("###xparams.fldID#_datetime").val();	
			jQuery("###xparams.fldDateTime#").val(apprvlDateTime);
		}	  
		</cfif>
			
		// Set the Denial Msg Field visability if the Denial Msg Field ID binding is set  
		<cfif LEN(TRIM(xparams.fldDenialMsg))>
		function showHideDenialMsg_#fqFieldName#(){	  
			var deniedCheckboxStatus = jQuery('###xparams.fldID#_checkbox_denied').attr("checked");
			var storedFieldValue = jQuery('input[name=#fqFieldName#]').val();
			
			// Find the Current Row and the Next Row (if it contains a description)
			jQuery.thisTableRow = jQuery("###xparams.fldDenialMsg#").parents("tr:first");
			jQuery.nextTableRow = jQuery("###xparams.fldDenialMsg#").parents("tr").next("tr");
			jQuery.hasFieldDscrpt = jQuery.nextTableRow.find(".CS_Form_Description");

			// if the deniedCheckboxStatus is true show the Denial Msg Field
			if ( deniedCheckboxStatus && storedFieldValue == '#xparams.deniedVal#' ) {
				jQuery.thisTableRow.show('slow');
				if ( jQuery.hasFieldDscrpt ) {	
					jQuery.nextTableRow.show('slow');
				}
			}
			else {
				jQuery.thisTableRow.hide('slow');
				if ( jQuery.hasFieldDscrpt ) {
					jQuery.nextTableRow.hide('slow');
				}
				jQuery("###xparams.fldDenialMsg#").val("");	
			}
			apprvResizeWindow();			
		}
		
		function apprvResizeWindow(){
			setTimeout( function() {
				ResizeWindow();
			}, 1000 );			
		}
		</cfif>	  	
	</script>
	
<!---
	This version is using the wrapFieldHTML functionality, what this does is it takes
	the HTML that you want to put into the TD of the right section of the display, you
	can optionally disable this by adding the includeLabel = false (fourth parameter)
	when false it simply creates a TD and puts your content inside it. This wrapper handles
	everything from description to simple form field handling.
--->

	<cfsavecontent variable="inputHTML">
		<cfscript>
		
//application.ptCalendar.utils.doDump(fieldPermission,"fieldPermission",1);
//application.ptCalendar.utils.doDump(variables.fieldPermission,"variables.fieldPermission",1);
//application.ptCalendar.utils.doDump(readOnly,"readOnly",1);	

//application.ptCalendar.utils.doDump(request.user.grouplist,"request.user.grouplist",1);	
//application.ptCalendar.utils.doDump(xparams.pedit,"xparams.pedit",1);			
//application.ptCalendar.utils.doDump(xparams.UseSecurity,"xparams.UseSecurity",1);
//application.ptCalendar.utils.doDump(xparams,"xparams",1);
			
			// Get the list permissions and compare
			//commonGroups = application.ptCalendar.data.ListInCommon(request.user.grouplist, xparams.pedit);			
			// Set the read only 
			//readOnly = true;
			// Check if the user does have edit permissions
			//if ( (xparams.UseSecurity EQ 0) OR ( (xparams.UseSecurity EQ 1) AND (ListLen(commonGroups)) ) )
				//readOnly = false;
		</cfscript>
		
		<cfoutput>
			<div id="#fqFieldName#_renderCheckbox">
				<!--- <input type='checkbox' name='#fqFieldName#_checkbox' id='#fqFieldName#_checkbox' value='yes' <cfif readOnly>readonly="true"</cfif>> --->
				<input type='checkbox' name='#fqFieldName#_checkbox' id='#xparams.fldID#_checkbox_approved'<cfif LEN(TRIM(xparams.fldClass))> class="#xparams.fldClass#"</cfif> value='1' <cfif readOnly>readonly="true"</cfif>><cfif LEN(TRIM(xparams.approvedLabel))><label for="#xparams.fldID#_checkbox_approved">&nbsp;#xparams.approvedLabel#</label></cfif>
				<!--- <input type='checkbox' name='#fqFieldName#_checkbox' id='#xparams.fldID#_denied'<cfif LEN(TRIM(xparams.fldClass))> class="#xparams.fldClass#"</cfif> value='0' <cfif readOnly>readonly="true"</cfif>> Denied --->
				<cfif LEN(TRIM(xparams.deniedVal))>	
				&nbsp;&nbsp;&nbsp;
				<input type='checkbox' name='#fqFieldName#_checkbox' id='#xparams.fldID#_checkbox_denied'<cfif LEN(TRIM(xparams.fldClass))> class="#xparams.fldClass#"</cfif> value='0' <cfif readOnly>readonly="true"</cfif>><cfif LEN(TRIM(xparams.deniedLabel))><label for="#xparams.fldID#_checkbox_denied">&nbsp;#xparams.deniedLabel#</label></cfif>
				</cfif>
			</div>
			<!--- hidden field to store the value --->
			<cfif cftDebug>Stored: </cfif><input type='#tempFieldsType#' name='#fqFieldName#' id='#xparams.fldID#' value='#currentValue#'><cfif cftDebug><br/></cfif>
			<cfif cftDebug>DateTime: </cfif><input type='#tempFieldsType#' name='#fqFieldName#_datetime' id='#xparams.fldID#_datetime' value='#csDateTimeStamp#'><cfif cftDebug><br/></cfif>
			<cfif cftDebug>UserID: </cfif><input type='#tempFieldsType#' name='#fqFieldName#_userid' id='#xparams.fldID#_userid' value='#request.user.id#'><cfif cftDebug><br/></cfif>
			<!--- <cfif cftDebug>Status: </cfif><input type='#tempFieldsType#' name='#fqFieldName#_status' id='#xparams.fldID#_status' value=''><cfif cftDebug><br/></cfif> --->
		</cfoutput>
	</cfsavecontent>
	
	<!---
		This CFT is using the forms lib wrapFieldHTML functionality. The wrapFieldHTML takes
		the Form Field HTML that you want to put into the TD of the right section of the CFT 
		table row and helps with display formatting, adds the hidden simple form fields (if needed) 
		and handles field permissions (other than read-only).
		Optionally you can disable the field label and the field discription by setting 
		the includeLabel and/or the includeDescription variables (found above) to false.  
	--->
	#application.ADF.forms.wrapFieldHTML(inputHTML,fieldQuery,attributes,variables.fieldPermission,includeLabel,includeDescription)#
</cfoutput>