<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
 
Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.
 
The Original Code is comprised of the PT Calendar directory
 
The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2013.
All Rights Reserved.
 
By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable
end user license agreement.
--->
<!---
/* *************************************************************** */
Author: 	
	PaperThin, Inc.
	G. Cronkright 
Custom Field Type:
	Calendar Organization Radio Buttons Field
Name:
	calendar_org_radio_buttons_render.cfm
Summary:
	Custom Field to select Organizations from Radio Button list
	with a select all option. Also can be bound to the event category 
	checkbox field to display category checkbox options based on the selected
	organization
ADF Requirements:
	scripts_1_0
	ptCalendar.calOrganizationsDAO
History:
	2011-08-18 - GAC - Created
	2013-09-19 - GAC - Added a renderField option to allow the field to be hidden
--->
<cfscript>
	// the fields current value
	currentValue = attributes.currentValues[fqFieldName];
	// the param structure which will hold all of the fields from the props dialog
	xparams = parameters[fieldQuery.inputID];
	
	if ( NOT StructKeyExists(xparams,"orgFieldID") OR LEN(TRIM(xparams.orgFieldID)) EQ 0 )
		xparams.orgFieldID = TRIM(ReplaceNoCase(fqFieldName,'fic_',''));
	else
		xparams.orgFieldID = TRIM(xparams.orgFieldID);
		
	if ( NOT StructKeyExists(xparams,"catFieldID") )
		xparams.catFieldID = "";
	else
		xparams.catFieldID = TRIM(xparams.catFieldID);
	
	// Set the defaults
	if( StructKeyExists(xParams, "forceScripts") AND (xParams.forceScripts EQ "1") )
		xParams.forceScripts = true;
	else
		xParams.forceScripts = false;

	if( StructKeyExists(xParams, "useOnlyAciveOrgs") AND (xParams.useOnlyAciveOrgs EQ "1") )
		xParams.useOnlyAciveOrgs = true;
	else
		xParams.useOnlyAciveOrgs = false;
	
	if( StructKeyExists(xParams, "useALLoption") AND (xParams.useALLoption EQ "1") )
		xParams.useALLoption = true;
	else
		xParams.useALLoption = false;
		
	if( NOT StructKeyExists(xParams, "allOptionLabel") )
		xParams.allOptionLabel = ""; // Default is blank since the App should use a value from the Config: All Organizations
		
	if( NOT StructKeyExists(xParams, "allOptionValueType") )
		xParams.allOptionValueType = "useconfig";	// 'none', 'all', 'custom' or 'useconfig'
	
	if( NOT StructKeyExists(xParams, "allOptionValue") )
		xParams.allOptionValue = "";
	
	if ( NOT StructKeyExists(xParams,"defaultOptionType") )
		xParams.defaultOptionType = "useconfig"; // 'none', 'all', 'record' or 'useconfig'
	
	if( NOT StructKeyExists(xParams, "defaultOptionValue") )
		xParams.defaultOptionValue = "";
	
	// Allow the Config value to be overriden via the Field Props (for now!)
	if( NOT StructKeyExists(xParams, "optionSortField") OR LEN(TRIM(xParams.optionSortField)) EQ 0 OR xParams.optionSortField EQ "useconfig" ) {
		// Orgs Sort Field from the Confing
		xParams.optionSortField = application.ptCalendar.getOrgsDisplaySortField();
	} // else 'name' or 'ordinal'	
	
	if( NOT StructKeyExists(xParams, "renderField") )
		xParams.renderField = "yes";
	
/*
xParams.defaultSelectedOption (old)
*  
defaultValues.allOptionLabel = ""; // Default is blank since the App with use a value from the Config: All Organizations
defaultValues.allOptionValueType = "useconfig"; // 'none', 'all', 'custom' or 'useconfig'
defaultValues.allOptionValue = "";	
defaultValues.defaultOptionType = "useconfig"; // 'none', 'record' or 'useconfig'
defaultValues.defaultOptionValue = "";
*/
	
	// Get Organization ID and Names Structure to build the radio button list
	if ( LEN(TRIM(xParams.optionSortField)) )
		orgData = application.ptCalendar.calOrganizationsDAO.getCalOrgIDandNameArray(activeOnly=xParams.useOnlyAciveOrgs,sortField=TRIM(xParams.optionSortField));
	else
		orgData = application.ptCalendar.calOrganizationsDAO.getCalOrgIDandNameArray(activeOnly=xParams.useOnlyAciveOrgs);

	// Set the Label from config of the All Orgs option is blank	
	if ( LEN(TRIM(xParams.allOptionLabel)) EQ 0 ) {
		xParams.allOptionLabel = application.ptCalendar.getAllOrganizationsLabel();
	}
	
	// Share this value with the category Checkbox CFT... if needed
	request.params.allOrgsOptionValue = "";
	// Build a comma-delimited list of ALL available options
	if ( xParams.allOptionValueType EQ "all" ) {
		request.params.allOrgsOptionValue = "--[all]--";
		/*for ( x=1;x LTE ArrayLen(orgData); x=x+1){
			request.params.allOrgsOptionValue = ListAppend(request.params.allOrgsOptionValue,orgData[x].uniqueID);
		}*/
	}
	// Set the allOptionValue from the props value 
	else if ( xParams.allOptionValueType EQ "custom" ) {
		request.params.allOrgsOptionValue = xParams.allOptionValue;
	}
	// Set the allOptionValue from config 
	else if ( xParams.allOptionValueType EQ "useconfig" ) {    
		request.params.allOrgsOptionValue = application.ptCalendar.getAllOrganizationsValue();
	}
	// aka. allOptionValueType = none
	else {
		request.params.allOrgsOptionValue = "";
	}

	// Set the Default Value to be selected if the currentValue has not been set
	if ( LEN(TRIM(currentValue)) EQ 0 ) {
		if ( xParams.defaultOptionType EQ "record" ) {
			currentValue = xParams.defaultOptionValue;
		}
		else if ( xParams.defaultOptionType EQ "all" ) {
			for ( x=1;x LTE ArrayLen(orgData); x=x+1){
				currentValue = ListAppend(currentValue,orgData[x].uniqueID);
			}
		}
		else if ( xParams.defaultOptionType EQ "custom" ) {
			currentValue = xParams.defaultOptionValue;
		}
		else if ( xParams.defaultOptionType EQ "useconfig" ) {
			currentValue = application.ptCalendar.getAllOrganizationsDefaultValue();
		}
		// aka. defaultOptionType = none
		else {
			currentValue = "";	
		}
	}
	else {
		// Select the item that matches the currentValue
	}
	
/*
	allOrgsOptionLabel = "";
	allOrgsDefaultValue = application.ptCalendar.getAllOrganizationsDefaultValue();
	
	// Set the Value of the All option
	allOrgsOptionValue = "";
	if ( xParams.allOptionValue EQ "all" ) {
		for ( x=1;x LTE ArrayLen(orgData); x=x+1){
			allOrgsOptionValue = ListAppend(allOrgsOptionValue,orgData[x].uniqueID);
		}
	} 
	else if ( xParams.allOptionValue EQ "useconfig" ) {
		allOrgsSelectedValue = application.ptCalendar.getAllOrganizationsDefaultValue();
		allOrgsOptionValue=allOrgsSelectedValue;
	}
*/

/*
	// Set the Default Value to be selected
	if ( LEN(TRIM(xParams.defaultOptionValue)) AND LEN(TRIM(currentValue)) EQ 0 ) {
		// If the default selection text and the all optionlabel text are eq us the IDs for all the options (allOrgsOptionValue)
		if ( xParams.defaultSelectedOption EQ xParams.allOptionLabel ) {
			currentValue = allOrgsOptionValue;
		}
		// Else determine which ID should be used by matching it to the available options
		else {	
			for ( y = 1; y LTE ArrayLen(orgData); y=y+1){
				if ( TRIM(orgData[y].name) EQ TRIM(xParams.defaultSelectedOption) ) {
					currentValue = orgData[y].uniqueID;	
					break;
				}
			}
		}	
	}
*/
	
	// Set defaults for the label and description 
	includeLabel = true;
	includeDescription = true; 

	if ( xParams.renderField EQ "no" ) {
		includeLabel = false;
		includeDescription = false;
	}

	//-- Update for CS 6.x / backwards compatible for CS 5.x --
	//   If it does not exist set the Field Permission variable to a default value
	if ( NOT StructKeyExists(variables,"fieldPermission") )
		variables.fieldPermission = "";

	//-- Read Only Check w/ cs6 fieldPermission parameter --
	readOnly = application.ADF.forms.isFieldReadOnly(xparams,variables.fieldPermission);

	// Load JQuery to the script
	application.ptCalendar.scripts.loadJQuery(force=xParams.forceScripts);	
</cfscript>

<cfoutput>
	<script>
		// javascript validation to make sure they have text to be converted
		#fqFieldName#=new Object();
		#fqFieldName#.id='#fqFieldName#';
		#fqFieldName#.tid=#rendertabindex#;
		#fqFieldName#.validator = "validate_#fqFieldName#()";
		#fqFieldName#.msg = "Please select a value for the #xparams.label# field.";
		// Check if the field is required
		if ( '#xparams.req#' == 'Yes' ) {
			// push on to validation array
			vobjects_#attributes.formname#.push(#fqFieldName#);
		}
		
		function validate_#fqFieldName#() {
			if (jQuery("input[name=#fqFieldName#]").val() != '') {
				return true;
			}
			else {
				alert(#fqFieldName#.msg);
				return false;
			}
		}
		
		jQuery(function(){
			
			/* TRIGGER THE CATEGORIES TO LOAD FOR THE SELECTED ORG */
			<cfif LEN(TRIM(xparams.catFieldID))>
				
				<cfset currentSelectedOrgValue = currentValue>
				<cfif LEN(TRIM(currentvalue)) AND xParams.allOptionValueType NEQ 'none'>
					<!--- // Check the currentValue matches the All Orgs Value --->
					<!--- // - If it does set it 'no value' to pass the the category checkbox field --->
					<cfif xParams.allOptionValueType EQ "useconfig" AND currentValue EQ request.params.allOrgsOptionValue>
						<cfset currentSelectedOrgValue = ''>
					</cfif>

					// loadCategories_#xparams.catFieldID#() - JS function in the Event Category Checkboxes CFT
					loadCategories_#xparams.catFieldID#('#currentSelectedOrgValue#');
				<cfelseif xParams.allOptionValueType NEQ 'none'>
					<!--- //TODO: other props still need work!!! --->
					
					// loadCategories_#xparams.catFieldID#() - JS function in the Event Category Checkboxes CFT
					loadCategories_#xparams.catFieldID#('#currentSelectedOrgValue#');
				<cfelse>
					// Show a 'Selected an Org' message in the Cat Field if no Org has be selected/
					// - 'No Org Selected' msg JS function in the Event Category Checkboxes CFT	
					loadCategoriesNoneSelectedMsg_#xparams.catFieldID#(); 
				</cfif> 
							
<!--- // TODO: DO NOT USE - for reference only --->				
<!--- <cfif LEN(TRIM(currentvalue))>
	<cfif xParams.allOptionValueType EQ "useconfig" AND currentvalue EQ request.params.allOrgsOptionValue>
		loadCategories_#xparams.catFieldID#('');
	<cfelse>
		// loadCategories_#xparams.catFieldID#() - JS function in the Event Category Checkboxes CFT
		loadCategories_#xparams.catFieldID#('#currentvalue#');
	</cfif>
<cfelseif LEN(TRIM(currentvalue)) EQ 0 AND xParams.defaultOptionType EQ "none">
	loadCategories_#xparams.catFieldID#('');
<cfelse>		
	// Show a 'Select an Org' message in the Cat Field if no Org has be selected
	loadCategoriesNoneSelectedMsg_#xparams.catFieldID#(); // - 'No Org Selected' msg JS function in the Event Category Checkboxes CFT	
</cfif> --->

<!--- // TODO: DO NOT USE - for reference only --->	
<!--- <cfif xParams.defaultOptionType EQ "record">

<cfelseif xParams.defaultOptionType EQ "all">

<cfelseif xParams.defaultOptionType EQ "custom">

<cfelseif xParams.defaultOptionType EQ "useconfig">

<cfelseif xParams.defaultOptionType EQ "none">

</cfif> --->

<!--- // TODO: DO NOT USE - for reference only --->
<!--- <cfif LEN(TRIM(currentvalue))>
	// loadCategories_#xparams.catFieldID#() - JS function in the Event Category Checkboxes CFT
	loadCategories_#xparams.catFieldID#('#currentvalue#');
<cfelse>
	// TODO: Add Props option to select whether to return ALL cats or to return NONE
	// This function currently returns ALL categories
	//loadCategories_#xparams.catFieldID#(); 			// returns all
	//loadCategories_#xparams.catFieldID#('--none--');  // returns none
	
	// Show a 'Selected an Org' message in the Cat Field if no Org has be selected
	loadCategoriesNoneSelectedMsg_#xparams.catFieldID#(); // - 'No Org Selected' msg JS function in the Event Category Checkboxes CFT	
</cfif> --->

			</cfif>	
			
			// On the Click of a Radio Button add the Value to the hidden field 
			// - If Binding exists... load the related CATEGORIES for this ORG
			jQuery("input[name='#xparams.orgFieldID#_radiobutton']").click(function(){	
				var catParentItem = '';
				var selectedItem = jQuery("input[name='#xparams.orgFieldID#_radiobutton']:checked").val();
				<cfif LEN(TRIM(xparams.catFieldID)) AND xParams.allOptionValueType EQ "useconfig">
					if ( selectedItem == '#request.params.allOrgsOptionValue#' )
						catParentItem = '';
					else 
						catParentItem = selectedItem;
				</cfif>

<!--- // TODO: DO NOT USE - for reference only --->
<!--- <cfif xParams.allOptionValueType EQ "all">
	if ( selectedItem == '#request.params.allOrgsOptionValue#' ) {
		selectedItem = "";				
	}
</cfif> --->

<!--- // TODO: DO NOT USE - for reference only --->			
<!--- if ( selectedItem == '#request.params.allOrgsOptionValue#' ) {
	selectedItem = '#request.params.allOrgsOptionValue#';
	<cfif xParams.allOptionValueType EQ "all">
		selectedItem = '#request.params.allOrgsOptionValue#';
	<cfelse>
		selectedItem = '';
	</cfif> 
}--->
				
				jQuery("###xparams.orgFieldID#").val(selectedItem);
				jQuery(this).blur();
				
				<!--- }
				else {
					jQuery("###xparams.orgFieldID#").val(selectedItem);
					jQuery(this).blur();			
				} --->

				// On click load the categories for the selected organization (and clear old selections)
				<cfif LEN(TRIM(xparams.catFieldID))>
				// loadCategories_#xparams.catFieldID#() - JS function in the Event Category Checkboxes CFT
				// - with loadCurrentSelections set to false
				loadCategories_#xparams.catFieldID#(catParentItem,false);
				</cfif>
			});
		});
	</script> 

	<cfsavecontent variable="inputHTML">
		<cfoutput>
			<!--- >xParams.allOptionValue: #xParams.allOptionValue# --->
			
			<div id="#xparams.orgFieldID#_orgOptionsBox"<cfif xParams.renderField EQ "no"> style="display:none;"</cfif>>
				<cfif xParams.useALLoption>
					<cfif xParams.allOptionValueType EQ "all">
						<div class="#xparams.orgFieldID#_orgOptionItem"><input type='radio' name='#xparams.orgFieldID#_radiobutton' id='#xparams.orgFieldID#_radiobutton_all' class="customRadioBtn" value='--[all]--'<cfif ListLen(application.ptCalendar.data.ListInCommon(TRIM(currentValue),TRIM(request.params.allOrgsOptionValue))) EQ ListLen(TRIM(request.params.allOrgsOptionValue)) AND ListLen(TRIM(request.params.allOrgsOptionValue)) NEQ 0> checked="checked"</cfif>>&nbsp;<label for='#xparams.orgFieldID#_radiobutton_all'>#xParams.allOptionLabel#</label></div>
					<cfelseif xParams.allOptionValue EQ "none">
						<div class="#xparams.orgFieldID#_orgOptionItem"><input type='radio' name='#xparams.orgFieldID#_radiobutton' id='#xparams.orgFieldID#_radiobutton_all' class="customRadioBtn" value=''<cfif TRIM(currentValue) EQ 0> checked="checked"</cfif>>&nbsp;<label for='#xparams.orgFieldID#_radiobutton_all'>#xParams.allOptionLabel#</label></div>
					<cfelse>
						<div class="#xparams.orgFieldID#_orgOptionItem"><input type='radio' name='#xparams.orgFieldID#_radiobutton' id='#xparams.orgFieldID#_radiobutton_all' class="customRadioBtn" value='#request.params.allOrgsOptionValue#'<cfif TRIM(request.params.allOrgsOptionValue) EQ TRIM(currentValue)> checked="checked"</cfif>>&nbsp;<label for='#xparams.orgFieldID#_radiobutton_all'>#xParams.allOptionLabel#</label></div>
					</cfif>
				</cfif>
				<cfif ArrayLen(orgData)>
					<cfloop from="1" to="#ArrayLen(orgData)#" index="itm">
						<div class="#xparams.orgFieldID#_orgOptionItem"><input type='radio' name='#xparams.orgFieldID#_radiobutton' id='#xparams.orgFieldID#_radiobutton_#itm#' class="customRadioBtn" value='#orgData[itm].uniqueID#'<cfif orgData[itm].uniqueID EQ currentValue> checked="checked"</cfif>>&nbsp;<label for='#xparams.orgFieldID#_radiobutton_#itm#'>#orgData[itm].name#</label></div> 
					</cfloop> 
				</cfif>
			</div>
			
			<!--- // hidden field to store the values --->
			<input type='hidden' name='#fqFieldName#' id='#xparams.orgFieldID#' value='#currentValue#'>
		</cfoutput>
	</cfsavecontent>
	
	<!---
		This CFT is using the forms lib wrapFieldHTML functionality. The wrapFieldHTML takes
		the Form Field HTML that you want to put into the TD of the right section of the CFT 
		table row and helps with display formatting, adds the hidden simple form fields (if needed) 
		and handles field permissions (other than read-only).
		Optionally you can disable the field label and the field discription by setting 
		the includeLabel and/or the includeDescription variables (found above) to false.  
	--->
	
	#application.ADF.forms.wrapFieldHTML(inputHTML,fieldQuery,attributes,variables.fieldPermission,includeLabel,includeDescription)#
</cfoutput>