<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the PT Calendar directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2013.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable 
end user license agreement.
--->
<!---
/* *************************************************************** */
Author: 	
	PaperThin, Inc.
	G. Cronkright 
Custom Field Type:
	Event Category Checkbox Field
Name:
	event_category_checkboxes_render.cfm
Summary:
	Custom Field to select event categories from a list of checkboxes. 
	These categories can be bound to the Calendar Organizations radio button
	field. When a different organization is selected that organizations 
	associated category checkboxes are rendered.
History:
	2011-08-18 - GAC - Created
--->
<cfscript>
	// the fields current value
	currentValue = attributes.currentValues[fqFieldName];
	// the param structure which will hold all of the fields from the props dialog
	xparams = parameters[fieldQuery.inputID];

	//--Field Security--
	readOnly = application.ADF.forms.isFieldReadOnly(xparams);
	
	if ( NOT StructKeyExists(xparams,"catFieldID") OR LEN(TRIM(xparams.catFieldID)) EQ 0 )
		xparams.catFieldID = TRIM(ReplaceNoCase(fqFieldName,'fic_',''));
	else
		xparams.catFieldID = TRIM(xparams.catFieldID);
	
	if ( NOT StructKeyExists(xparams,"orgFieldID") )
		xparams.orgFieldID = "";
	else
		xparams.orgFieldID = TRIM(xparams.orgFieldID);
	
	if ( NOT StructKeyExists(xparams,"catFieldNoneMsg") OR LEN(TRIM(xparams.catFieldNoneMsg)) EQ 0 )
		xparams.catFieldNoneMsg = "No Categories were found";
	else
		xparams.catFieldNoneMsg = TRIM(xparams.catFieldNoneMsg);
		
	if ( NOT StructKeyExists(xparams,"orgFieldNoneMsg") OR LEN(TRIM(xparams.orgFieldNoneMsg)) EQ 0 )
		xparams.orgFieldNoneMsg = "Please select an Organization";
	else
		xparams.orgFieldNoneMsg = TRIM(xparams.orgFieldNoneMsg);	
	
	if( StructKeyExists(xParams, "useOnlyAciveCats") AND (xParams.useOnlyAciveCats EQ "1") )
		xParams.useOnlyAciveCats = true;
	else
		xParams.useOnlyAciveCats = false;
	
	if( StructKeyExists(xParams, "forceScripts") AND (xParams.forceScripts EQ "1") )
		xParams.forceScripts = true;
	else
		xParams.forceScripts = false;
	
	// Allow the Config value to be overriden via the Field Props (for now!)
	if( NOT StructKeyExists(xParams, "optionSortField") OR LEN(TRIM(xParams.optionSortField)) EQ 0 OR xParams.optionSortField EQ "useconfig" ) {
		// Orgs Sort Field from the Confing
		xParams.optionSortField = application.ptCalendar.getCatsDisplaySortField();
	} // else 'name' or 'ordinal'	
	
	allOrgsSelectedValue = "";
	if ( LEN(TRIM(xparams.orgFieldID)) AND StructKeyExists(request.params,"allOrgsSelectedValue") ) {
		// Get the Default 'All Organizations' Values from the Organization Radio button CFT
		allOrgsSelectedValue = request.params.allOrgsSelectedValue;
	}
	else if ( LEN(TRIM(xparams.orgFieldID)) ) {
		// Get the Default 'All Organizations' Values from the Config
		allOrgsSelectedValue = application.ptCalendar.getAllOrganizationsDefaultValue(); 
	}

	// find if we need to render the simple form field
	renderSimpleFormField = false;
	if ( (StructKeyExists(request, "simpleformexists")) AND (request.simpleformexists EQ 1) )
		renderSimpleFormField = true;
		
//application.ADF.utils.doDump(renderSimpleFormField,"renderSimpleFormField",1);

	ajaxLoadingHTML = 'Loading Categories...<img src="/ADF/lib/ajax/images/ajax-loader-arrows.gif">';
	
	application.ptCalendar.scripts.loadjQuery(force=xParams.forceScripts);
	application.ptCalendar.scripts.loadCFJS();
	application.ptCalendar.scripts.loadJQueryCheckboxes();
</cfscript>
<cfoutput>
	<script>
		// javascript validation to make sure they have text to be converted
		#fqFieldName#=new Object();
		#fqFieldName#.id='#fqFieldName#';
		#fqFieldName#.tid=#rendertabindex#;
		#fqFieldName#.msg="Please select a value for the #xparams.label# field.";
		#fqFieldName#.validator = "validate_#fqFieldName#()";

		//If the field is required
		if ( '#xparams.req#' == 'Yes' ) {
			// push on to validation array
			vobjects_#attributes.formname#.push(#fqFieldName#);
		}

		//Validation function
		function validate_#fqFieldName#(){
			if (jQuery("input[name=#fqFieldName#]").val() != '') {
				return true;
			}
			else {
				return false;
			}
		}
		
		jQuery(function(){
			jQuery("###fqFieldName#_LoadingStatus").hide();
			
			<cfif LEN(TRIM(xparams.catFieldID)) AND LEN(TRIM(xparams.orgFieldID)) EQ 0>
			// Load the Cats here... if the ORG field is not Bound via the PROPS
			loadCategories_#xparams.catFieldID#();
			</cfif>
		});
		
		<cfif LEN(TRIM(xparams.orgFieldID))>
		// Set up what to display if no value is passed from the orgFileID
		function loadCategoriesNoneSelectedMsg_#xparams.catFieldID#(){
			var htmlString = '';
			htmlString = '<label>';
			htmlString = htmlString + "#xparams.orgFieldNoneMsg#";
			htmlString = htmlString + '</label>';
			jQuery("table###fqFieldName#_cbTable").html(htmlString);	
		}
		</cfif>
		
		function clearCheckedCategories_#xparams.catFieldID#() {
			// Clear all the checkboxes
			jQuery("table###fqFieldName#_cbTable").empty();
			// jQuery("input[name='#fqFieldName#_checkbox']:checkbox").unCheckCheckboxes();
			jQuery("input[name='#fqFieldName#']").val(''); 	
		}
		
		<!--- // We need to use the xparams.catFieldID because this function may be triggered by the Organizations CFT --->
		function loadCategories_#xparams.catFieldID#(selectedOrgValue,loadCatSelections) {
			// if no selectedOrgValue is passed in then set it to an empty string
			selectedOrgValue = typeof selectedOrgValue !== 'undefined' ? selectedOrgValue : "";
			// if loadCatSelections is not passed in then set it to 'true'
			loadCatSelections = typeof loadCatSelections !== 'undefined' ? loadCatSelections : "true";
			
			var htmlString = '';
			
			// if the selectedOrgValue that is passed in matches the AllOrganizationsDefaultValue 
			// then reset the selectedOrgValue to an empty string to return all categories
			if ( selectedOrgValue == '#allOrgsSelectedValue#' ) {
				selectedOrgValue = '';
			}
			
			// Show Loading after process has run
			jQuery("###fqFieldName#_LoadingStatus").show();
			//jQuery("table###xparams.catFieldID#_catOptionsBox").slideUp(3000);
			
			// Remove all of the current checkbox input fields
			jQuery("table###fqFieldName#_cbTable").empty();
			// Clear all the checkboxes
			// jQuery("input[name='#fqFieldName#_checkbox']:checkbox").unCheckCheckboxes();
			// Remove the current values
			jQuery("input[name='#fqFieldName#']").val('');

			// Set the key value pairs to pass the the Ajax function
			var ajaxPostVars = { 
									appName: "ptCalendar",
									bean: "calEventCategoriesDAO",
									method: "getFilteredCategoriesByOrgID",
									orgID: selectedOrgValue,
									<cfif xParams.useOnlyAciveCats>
									filterField: "active",
									filterValue: 1,
									</cfif>
									<cfif LEN(TRIM(xParams.optionSortField))>
									sortField: '#xParams.optionSortField#',
									</cfif>
									returnformat: "json"
								}; 
								
			// Get the selected Categories
			jQuery.post("#application.ADF.ajaxProxy#",
				ajaxPostVars,
				function(results) {
					if ( results.length >=1 ) {
						for ( i=0; i < results.length; i++ ) {
							htmlString = htmlString + addCSCheckbox_#fqFieldName#(results[i].VALUES.catID,results[i].VALUES.name,0,i,results.length);
						}
						jQuery("table###fqFieldName#_cbTable").append(htmlString);
					}
					else {
						htmlString = '<label>';
						htmlString = htmlString + "#xparams.catFieldNoneMsg#";
						htmlString = htmlString + '</label>';
						jQuery("table###fqFieldName#_cbTable").html(htmlString);				
					}
					
					
					if ( loadCatSelections ) {
						// add the checks to the selected checkboxs 
						loadCurrentSelectedValues_#fqFieldName#();
					}
					
					// Load Click event for Dynamic Checkboxes
					loadCheckBoxActions_#fqFieldName#();
					
					// Hide Loading after process has run
					jQuery("###fqFieldName#_LoadingStatus").hide();
					//jQuery("table###xparams.catFieldID#_catOptionsBox").slideDown(3000);	
					
					<!--- <cfif NOT renderSimpleFormField> --->
					//lbResizeWindow();
					<!--- </cfif> --->	
					// Resize Lightbox window
					if ( typeof lbResizeWindow == 'function' )
						lbResizeWindow();
					else if ( typeof ResizeWindow == 'function' )
						ResizeWindow();		
				},
				"json"
			);
			
			// Hide Loading after process has run
			//jQuery("###fqFieldName#_LoadingStatus").hide();	
		}
		
		function loadCurrentSelectedValues_#fqFieldName#(){		
			var selectedCats = '#currentValue#';
			for (i=1; i <= jQuery.ListLen(selectedCats); i++) {
				currentVal = "input[value="+jQuery.ListGetAt(selectedCats,i)+"]";
				//console.dir(jQuery(currentVal));
				jQuery(currentVal).attr('checked', true);
			}
			// Make sure the hidden field has the correct values 
			jQuery("input[name='#fqFieldName#']").val(selectedCats);
		}

		function addCSCheckbox_#fqFieldName#(uuid,name,rowbreak,currentRow,totalRows) {
			var html = '';
			var rowBreak = 2;
			var renderRowStart = false;
			var renderRowEnd = false;

			if (currentRow % rowBreak == 0)
				renderRowStart = true;
			else 
				renderRowEnd = true;

			if (currentRow == totalRows)
				renderRowEnd = true;

			if (renderRowStart)
				html = '<tr>';

			html = html + '<td>';
			html = html + '<table cellpadding="0" cellspacing="0" border="0" summary=""><tr>';
			
			html = html + '<td><input type="checkbox" name="#fqFieldName#_checkbox" value="'+uuid+'" id="#fqFieldName#_checkbox_'+uuid+'"></td>';
			html = html + '<td style="vertical-align:baseline"><label for="#fqFieldName#_checkbox_'+uuid+'">&nbsp;'+name+'</label></td>';
			html = html + '<td>&nbsp;&nbsp;&nbsp;</td>';

			html = html + '</tr></table>';
			html = html + '</td>';
			
			if (renderRowEnd)
				html = html + '</tr>';
			
			return html;
		}
		
		// Function to load Events with edit and delete links 
		function loadCheckBoxActions_#fqFieldName#() {
			
			jQuery("input[name='#fqFieldName#_checkbox']").click(function(){
				var clickedVal = jQuery(this).val();
				var currentFieldVal = jQuery("input[name='#fqFieldName#']").val();
				var clickedIDpos = jQuery.ListFindNoCase(currentFieldVal,clickedVal);
				//console.log('Checked ID:' + checkedVal);
			
				// When it was clicked was the checkbox checked or unchecked 
				if ( jQuery(this).is(':checked') ) {
					// Add the checked CatID to value list in the CFT hidden field to store the checked options
					if ( !clickedIDpos ) {
						currentFieldVal = jQuery.ListAppend(currentFieldVal,clickedVal);
						jQuery("input[name='#fqFieldName#']").val(currentFieldVal);
					}
								
				}	
				else {
					// Remove the checked CatID from the value list in CFT hidden field to store the checked options
					if ( clickedIDpos ) {
						currentFieldVal = jQuery.ListDeleteAt(currentFieldVal,clickedIDpos);
						jQuery("input[name='#fqFieldName#']").val(currentFieldVal);
					}			
				}
		    });
		    
		}
	</script>
	
	<style>
		###fqFieldName#_LoadingStatus {
			font-size: 11px;
			display: none;
		}
	</style>
	
<!---
	This version is using the wrapFieldHTML functionality, what this does is it takes
	the HTML that you want to put into the TD of the right section of the display, you
	can optionally disable this by adding the includeLabel = false (fourth parameter)
	when false it simply creates a TD and puts your content inside it. This wrapper handles
	everything from description to simple form field handling.
--->

	<cfsavecontent variable="inputHTML">
		<cfoutput>
			<div id="#fqFieldName#_LoadingStatus">
				<span>#ajaxLoadingHTML#</span>
			</div>
			<div id="#fqFieldName#_catOptionsBox">
				<table id="#fqFieldName#_cbTable"><tr><td>#ajaxLoadingHTML#</td></tr></table>
			</div>
			<!--- // hidden field to store the values --->
			<input type='hidden' name='#fqFieldName#' id='#xparams.catFieldID#' value='#currentValue#'>
		</cfoutput>
	</cfsavecontent>
	#application.ADF.forms.wrapFieldHTML(inputHTML,fieldQuery,attributes)#
</cfoutput>