<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
 
Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.
 
The Original Code is comprised of the PT Calendar directory
 
The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2013.
All Rights Reserved.
 
By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable
end user license agreement.
--->
<!---
/* *************************************************************** */
Author: 	
	PaperThin Inc.
	G. Cronkright
Name:
	calendar_recurrence_builder_render.cfm
Summary:
	Custom field to build the Event recurrence records for the Calendar App.
ADF App:
	PT Calendar
Version:
	3.0.0
History:
	2011-06-23 - GAC - Created
--->
<cfscript>
	// If the ptCalendar bean name has been defined get the app config
	if ( StructKeyExists(application,"ptCalendar") )
		appConfig = application.ptCalendar.getAppConfig();
	else
		appConfig = StructNew();
	
	// Set the UI theme from the Configuration Element
	uiTheme = application.ptCalendar.getUItheme();
	
	// Add/Edit button default labels
	rbAddButtonText = "Setup Recurrence";
	rbEditButtonText = "Edit Recurrence";
	
	rbController = "recurrenceBuilderController";
	rbService = "recurrenceBuilderService";
	rbForm = "recurrenceBuilderForms";

	// the fields current value
	currentValue = attributes.currentValues[fqFieldName];
	
	// the param structure which will hold all of the fields from the props dialog
	xparams = parameters[fieldQuery.inputID];
	
	// Set defaults for the label and description 
	includeLabel = true;
	includeDescription = false; 
	
	//-- Update for CS 6.x / backwards compatible for CS 5.x --
	//   If it does not exist set the Field Security variable to a default value
	if ( NOT StructKeyExists(variables,"fieldPermission") )
		variables.fieldPermission = "";
		
	//-- Read Only Check w/ cs6 fieldPermission parameter --
	readOnly = application.ADF.forms.isFieldReadOnly(xparams,variables.fieldPermission);
	
	if ( NOT StructKeyExists(xparams, "fieldID") )
		xparams.fieldID = fqFieldName;
	if ( (NOT StructKeyExists(xparams, "fieldClass")) OR ( LEN(TRIM(xparams.fieldClass)) LTE 0) )
		xparams.fieldClass = "";	
	if ( (NOT StructKeyExists(xparams, "btnAddText")) OR ( LEN(TRIM(xparams.btnAddText)) LTE 0) )
		xparams.btnAddText = rbAddButtonText;
	if ( (NOT StructKeyExists(xparams, "btnEditText")) OR ( LEN(TRIM(xparams.btnEditText)) LTE 0) )
		xparams.btnEditText = rbEditButtonText;
	
	// Set the NO Records Text
	noRecordsText = "Recurrence has not been setup for this event.<br/>Click '#xparams.btnAddText#' to select recurrence properties.";

	// Get the DateTime element Name
	dtDataElementName = application.ptCalendar.getEventDateTimeCEName();
	// Get the DateTime formid
	dtDataFormID = application.ptCalendar.getEventDateTimeFormID();
	// Set the the Ajax Loader Image
	ajaxIMG = '<img width="16" height="16" src="/ADF/apps/pt_calendar/images/ajax-loader-arrows.gif"/>';
	
	// Set the newDefaultPickerDate to be prepared if nothing is passed in 
	newDefaultPickerDate = "";
	
	if ( LEN(TRIM(currentValue)) EQ 0 ) {
		// Pass new date URL variable through to the Calendar Picker
		if ( StructKeyExists(request.params,"newSelectedDate") AND IsDate(request.params.newSelectedDate) )
			newDefaultPickerDate = request.params.newSelectedDate;	
	}
	
	// Create a script obj
	application.ptCalendar.scripts.loadJQuery();
	application.ptCalendar.scripts.loadJQueryUI(themeName=uiTheme);
	application.ptCalendar.scripts.loadADFLightbox();
</cfscript>

<cfoutput>
	<!--- Include the app CSS --->
	<link rel="stylesheet" type="text/css" href="/ADF/apps/pt_calendar/style/calendar-recurrence-builder.css">
	
	<style>
		a.addLink_#fqFieldName# {
			float:right;
			font-size: 10pt;
		}
	</style>
	
	<script>
		// javascript validation to make sure they have text to be converted
		#fqFieldName# = new Object();
		#fqFieldName#.id = '#fqFieldName#';
		#fqFieldName#.tid = '#rendertabindex#';
		#fqFieldName#.validator = "validate_#fqFieldName#()";
		#fqFieldName#.msg = "Please add a Date/Time entry.";
		// Check if the field is required
		if ( '#xparams.req#' == 'Yes' ) {
			// push on to validation array
			vobjects_#attributes.formname#.push(#fqFieldName#);
		}
		
		function validate_#fqFieldName#() {
			if (jQuery("input[name=#fqFieldName#]").val() != '')
			{
				return true;
			}
			else {
				return false;
			}
		}
	</script>
	
	<script>
		jQuery(function() {		
			// Get any Recurrence Properties that have been configured	
			renderRecurrence_#fqFieldName#();
			
			// add Recurrence without action page
			jQuery("##addRecurrenceLink_#fqFieldName#").click(function() {
				addRecurrence_#fqFieldName#();
			});
			
			// edit Recurrence without action page
			jQuery("##editRecurrenceLink_#fqFieldName#").click(function() {
				editRecurrence_#fqFieldName#();
			});
		});
			
			// Function to render the selected recurrence values for this field
			function renderRecurrence_#fqFieldName#() {
				// Sync the fieldValue with the element
				syncFieldValue_#fqFieldName#();
				
				var currVals = jQuery("input[name=#fqFieldName#]").val();
				
				if ( jQuery.trim(currVals).length ) {
					// If the field contains UUID values display the loading message
					jQuery("##display_#fqFieldName#").html('#ajaxIMG# Loading Recurrence...');
				}
				
				// load the recurrence data (or the no recurrence message)
				jQuery.get( "#application.ADF.ajaxProxy#",{ 	
					bean: "#rbController#"
					,method: 'renderRecurrenceHTML'
					,uuidlist: currVals
				},
				function(msg) {
					if ( jQuery.trim(msg).length ) {
						// Hide the 'Add Recurrence' button
						//jQuery("##addRecurrenceLink_#fqFieldName#").hide();
						
						// Show/Hide the Add and the Edit buttons
						jQuery("##addRecurrenceLink_#fqFieldName#").hide();
						jQuery("##editRecurrenceLink_#fqFieldName#").show();
						
						// Output the recurrence records or the no records message
						jQuery("##display_#fqFieldName#").html(msg);
						// Load the click handlers for the recurrence edit/delete links
						loadActionButtons_#fqFieldName#();
					}
					else {
						// Show the 'Add Recurrence' button
						//jQuery("##addRecurrenceLink_#fqFieldName#").show();	
						
						// Show/Hide the Add and the Edit buttons
						jQuery("##addRecurrenceLink_#fqFieldName#").show();
						jQuery("##editRecurrenceLink_#fqFieldName#").hide();
						
						// Display no records message
						msg = "<div class='recurrence-text'>#noRecordsText#</div>"
						
						// Display the NO RECORDS message
						jQuery("##display_#fqFieldName#").html(msg);			
					}
					// Resize Lightbox window
					if ( typeof lbResizeWindow == 'function' )
						lbResizeWindow();
					else if ( typeof ResizeWindow == 'function' )
						ResizeWindow();
				});
			}
			
			// Function to load Events with edit and delete links 
			function loadActionButtons_#fqFieldName#(){
			    // enable the trash can icon under the recurrence properties
			    jQuery("a.recurrence-builder-remove").click(function() { 
			    	var currUUID = jQuery(this).attr("id");
			    	removeRecurrenceItem_#fqFieldName#(currUUID);
			    });
			    
			    // Hover states on the static widgets
				jQuery("div.recurrence-builder-block div.ui-button").hover(
					function() { 
						jQuery(this).css("cursor", "hand");
						jQuery(this).addClass("ui-state-hover");
					},
					function() { 
						jQuery(this).css("cursor", "pointer");
						jQuery(this).removeClass('ui-state-hover');
					}
				);
			}
			
			// Use this function to keep event field value and recurrence element values in sync
			function syncFieldValue_#fqFieldName#() {
				var eventID = jQuery("##calEventID").val();
				var currVals = "";
				// get the current vals
				jQuery.get("#application.ADF.ajaxProxy#",{ 	
						bean: "#rbService#"
						,method: 'buildRecurrenceIDListByParentID'
						,parentID: eventID
					},
					function(data) {
						jQuery("input[name=#fqFieldName#]").val(data);
					}
				);
			} 

		/****************************/
		/*    CallBack Functions    */
		/****************************/
		
		// Callback function for the add/edit recurrence link
		function addEditRecurrence_cbFunct_#fqFieldName#(inArgsArray){
			var  recurrenceID = inArgsArray[0];
			var eventID = inArgsArray[1];
			var action = inArgsArray[2];
			
			// Update the fqFieldName field with the new UUID
			var currFieldVal = jQuery("input[name=#fqFieldName#]").val();
			
			// load the initial list items based on the top terms from the chosen facet
			jQuery.get( "#application.ADF.ajaxProxy#", { 	
				bean: "#rbService#",
				method: 'listManagement',
				currList: currFieldVal,
				currItem: recurrenceID,
				actionType: action
			},
			function(data) {
				// Set the value back into the save field
				jQuery("input[name=#fqFieldName#]").val(data);
				// Reload the render links content
				renderRecurrence_#fqFieldName#();
			});
		}
		// Callback function for the remove  recurrence link
		function remove_cbFunct_#fqFieldName#(cbValues) {
			// Close the current LB layer for the delete form
			closeLB();
			// Set the list management action
			var action = 'remove';
			// Set the RemoveID value from the passed in cbIDlist
			var removeID = "";
			if ( cbValues.hasOwnProperty("cbIDlist") ) 
				removeID = cbValues.cbIDlist;
				
			// Update the fqFieldName field with the new UUID
			var currFieldVal = jQuery("input[name=#fqFieldName#]").val();
						
			// load the initial list items based on the top terms from the chosen facet
			jQuery.get( "#application.ADF.ajaxProxy#",{ 	
				bean: "#rbService#",
				method: 'listManagement',
				currList: currFieldVal,
				currItem: removeID,
				actionType: action
			},
			function(data){
				// Set the value back into the save field
				jQuery("input[name=#fqFieldName#]").val(data);
				// Reload the recurrence properties 
				renderRecurrence_#fqFieldName#();
			});
		}
			
			
		/****************************/
		/*    UI Button Functions   */
		/****************************/
		
		// Function to open lightboxed form to delete recurrence from the trash can icon
		function removeRecurrenceItem_#fqFieldName#(recurrenceID) {
			openLB("#application.ADF.lightboxProxy#?bean=#rbForm#&method=renderRecurrenceDeleteForm&recurrenceID=" + recurrenceID + "&callback=remove_cbFunct_#fqFieldName#&cbIDlist=" + recurrenceID + "&title=Delete Recurrence Properties");
		}
		// Function to open lightboxed HTML form to add event recurrence
		function addRecurrence_#fqFieldName#() {
			var eventID = jQuery("##calEventID").val();
			<cfif LEN(TRIM(newDefaultPickerDate))>	
			openLB("#application.ADF.lightboxProxy#?bean=#rbForm#&method=renderRecurrenceHTMLForm&eventid=" + eventID + "&title=Add Recurrence Properties&callback=addEditRecurrence_cbFunct_#fqFieldName#&defaultDate=#newDefaultPickerDate#");
			<cfelse>
			openLB("#application.ADF.lightboxProxy#?bean=#rbForm#&method=renderRecurrenceHTMLForm&eventid=" + eventID + "&title=Add Recurrence Properties&callback=addEditRecurrence_cbFunct_#fqFieldName#");
			</cfif>
		}
		// Function to open lightboxed form to edit recurrence from the edit recurrence button
		function editRecurrence_#fqFieldName#() {
			var eventID = jQuery("##calEventID").val();
			var recurrenceID = jQuery("input[name=#fqFieldName#]").val();
			openLB("#application.ADF.lightboxProxy#?bean=#rbForm#&method=renderRecurrenceHTMLForm&recurrenceID=" + recurrenceID + "&eventid=" + eventID + "&callback=addEditRecurrence_cbFunct_#fqFieldName#&title=Edit Recurrence Properties");
		}
	</script>
	
	<!--- // Build the field inner HTML --->
	<cfsavecontent variable="inputHTML">
		<cfoutput>
			<div class="recurrence-builder-block">
				<!--- // LB Form Button --->
				<div id="addRecurrenceLink_#fqFieldName#" class="ui-button ui-state-default ui-corner-all">#xparams.btnAddText#</div>
				<div id="editRecurrenceLink_#fqFieldName#" class="ui-button ui-state-default ui-corner-all" style="display: none;">#xparams.btnEditText#</div>
				<div style="clear: both;"></div>
				<!--- // DIV where recurrence properties are loaded --->
				<div id="display_#fqFieldName#"></div>
				<!--- hidden field to store the value --->
				<input type="hidden" name="#fqFieldName#" value="#currentValue#" id="#xparams.fieldID#" class="#xparams.fieldClass#" size="40">
			</div>
		</cfoutput>
	</cfsavecontent>
	<!--- // Pass inner html to the wrapper function to format the CFT --->
	#application.ADF.forms.wrapFieldHTML(inputHTML,fieldQuery,attributes,variables.fieldPermission,includeLabel,includeDescription)#
</cfoutput>